import { Component, createEffect, createSignal } from 'solid-js';
import { useNavigate } from '@solidjs/router';
import { Geolocation } from '@awesome-cordova-plugins/geolocation';

import style from './GetLocation.module.css';
import LocationSearchingIcon from '@suid/icons-material/LocationSearching';
import { IconButton } from '@suid/material';
import { getState } from '../map';

export const [getCurrentLocation, setCurrentLocation] = createSignal<{
  lon: number;
  lat: number;
} | null>(null);

const GetLocation: Component = () => {
  const navigate = useNavigate();

  const onClickHandler = (event: any) => {
    console.log('Click handler');
    Geolocation.getCurrentPosition().then((position) => {
      console.log({ caller: 'GetLocation/onClickHandler', position });
      const state = getState();
      navigate(
        `/map/${position.coords.longitude}/${position.coords.latitude}/${state.zoom}/${state.rotation}`
      );
      setCurrentLocation({
        lon: position.coords.longitude,
        lat: position.coords.latitude,
      });
    });
  };

  //
  return (
    <IconButton class={style.getLocation} onClick={onClickHandler}>
      <LocationSearchingIcon />
    </IconButton>
  );
};

export default GetLocation;
